OnspringClient

Struct OnspringClient 

pub struct OnspringClient { /* private fields */ }
Client for interacting with the Onspring API v2.

Implementations

Source

impl OnspringClient

pub fn builder(api_key: impl Into<String>) -> OnspringClientBuilder

Creates a new OnspringClientBuilder.

Source

impl OnspringClient

pub async fn list_apps( &self, paging: Option<PagingRequest>, ) -> Result<PagedResponse<App>>

Gets all apps for the current client, with optional pagination.

pub async fn get_app(&self, app_id: i32) -> Result<App>

Gets an app by its identifier.

pub async fn batch_get_apps( &self, ids: &[i32], ) -> Result<CollectionResponse<App>>

Gets up to 100 apps by their identifiers.

Source

impl OnspringClient

pub async fn get_field(&self, field_id: i32) -> Result<Field>

Gets a field by its identifier.

pub async fn batch_get_fields( &self, ids: &[i32], ) -> Result<CollectionResponse<Field>>

Gets up to 100 fields by their identifiers.

pub async fn list_fields( &self, app_id: i32, paging: Option<PagingRequest>, ) -> Result<PagedResponse<Field>>

Gets a paginated list of fields for a given application.

Source

impl OnspringClient

pub async fn get_file_info( &self, record_id: i32, field_id: i32, file_id: i32, ) -> Result<FileInfo>

Gets a file’s metadata information.

pub async fn get_file( &self, record_id: i32, field_id: i32, file_id: i32, ) -> Result<FileResponse>

Downloads a file’s content.

pub async fn upload_file( &self, request: SaveFileRequest, ) -> Result<CreatedWithIdResponse>

Uploads a file attachment.

pub async fn delete_file( &self, record_id: i32, field_id: i32, file_id: i32, ) -> Result<()>

Deletes a file attachment.

Source

impl OnspringClient

pub async fn save_list_item( &self, list_id: i32, request: SaveListItemRequest, ) -> Result<SaveListItemResponse>

Creates or updates a list item in the specified list.

pub async fn delete_list_item(&self, list_id: i32, item_id: Uuid) -> Result<()>

Deletes a list item from the specified list.

Source

impl OnspringClient

pub async fn ping(&self) -> Result<()>

Checks if the Onspring API is reachable.

Source

impl OnspringClient

pub async fn list_records( &self, app_id: i32, paging: Option<PagingRequest>, field_ids: Option<&[i32]>, data_format: Option<DataFormat>, ) -> Result<PagedResponse<Record>>

Gets a paginated collection of records for a given app.

pub async fn get_record( &self, app_id: i32, record_id: i32, field_ids: Option<&[i32]>, data_format: Option<DataFormat>, ) -> Result<Record>

Gets a record by its identifier.

pub async fn save_record( &self, request: SaveRecordRequest, ) -> Result<SaveRecordResponse>

Creates or updates a record.

pub async fn delete_record(&self, app_id: i32, record_id: i32) -> Result<()>

Deletes a record by its identifier.

pub async fn batch_get_records( &self, request: BatchGetRecordsRequest, ) -> Result<CollectionResponse<Record>>

Gets a batch of records.

pub async fn query_records( &self, request: QueryRecordsRequest, paging: Option<PagingRequest>, ) -> Result<PagedResponse<Record>>

Queries records using a filter expression.

pub async fn batch_delete_records( &self, request: BatchDeleteRecordsRequest, ) -> Result<()>

Deletes a batch of records.

Source

impl OnspringClient

pub async fn get_report( &self, report_id: i32, data_format: Option<DataFormat>, data_type: Option<ReportDataType>, ) -> Result<ReportData>

Gets report data by report ID.

pub async fn list_reports( &self, app_id: i32, paging: Option<PagingRequest>, ) -> Result<PagedResponse<ReportInfo>>

Gets a paginated list of reports for a given application.